==> aliyun-python-sdk-actiontrail-2.0.0.tar.gz: aliyun-python-sdk-actiontrail-2.0.0/aliyunsdkactiontrail/request/v20171204/DescribeTrailsRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class DescribeTrailsRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Actiontrail', '2017-12-04', 'DescribeTrails','actiontrail')

	def get_Help(self):
		return self.get_query_params().get('Help')

	def set_Help(self,Help):
		self.add_query_param('Help',Help)

	def get_NameList(self):
		return self.get_query_params().get('NameList')

	def set_NameList(self,NameList):
		self.add_query_param('NameList',NameList)

	def get_Format(self):
		return self.get_query_params().get('Format')

	def set_Format(self,Format):
		self.add_query_param('Format',Format)

	def get_Type(self):
		return self.get_query_params().get('Type')

	def set_Type(self,Type):
		self.add_query_param('Type',Type)

	def get_Version(self):
		return self.get_query_params().get('Version')

	def set_Version(self,Version):
		self.add_query_param('Version',Version)

==> aliyun-python-sdk-actiontrail-2.0.2.tar.gz: aliyun-python-sdk-actiontrail-2.0.2/aliyunsdkactiontrail/request/v20171204/DescribeTrailsRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkactiontrail.endpoint import endpoint_data

class DescribeTrailsRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Actiontrail', '2017-12-04', 'DescribeTrails','actiontrail')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_IncludeShadowTrails(self):
		return self.get_query_params().get('IncludeShadowTrails')

	def set_IncludeShadowTrails(self,IncludeShadowTrails):
		self.add_query_param('IncludeShadowTrails',IncludeShadowTrails)

	def get_NameList(self):
		return self.get_query_params().get('NameList')

	def set_NameList(self,NameList):
		self.add_query_param('NameList',NameList)
